@@ -3,7 +3,7 @@ use strictures;
 use Gtk3;
 use RogersMine::App;
 
-our $VERSION = 0.1.11;
+our $VERSION = 0.1.12;
 
 sub main {
   my $window = Gtk3::Window->new('toplevel');
@@ -40,7 +40,7 @@ sub main {
 sub start_game {
   my ($rows, $cols, $lives, $risk, $btn, $evt) = @_;
   my $app = RogersMine::App->new(rows => $rows, cols => $cols, lives => $lives, risk => $risk);
-  $app->window->show_all;
+  $app->show;
 }
 
 1;
