@@ -4,7 +4,9 @@ use Moo;
 use strictures;
 use Gtk3;
 use RogersMine::MineField;
+use namespace::autoclean;
 
+has complete => (is => 'rw', default => sub { 0; });
 has rows => (is => 'ro');
 has cols => (is => 'ro');
 has lives => (is => 'ro');
@@ -22,7 +24,7 @@ has window => (is => 'lazy');
 
 sub _build_info {
   my $self = shift;
-  Gtk3::Label->new($self->minefield->lives);
+  Gtk3::Label->new($self->lives);
 }
 
 sub _build_window {
@@ -41,32 +43,32 @@ sub _build_window {
     $vbox->add($hbox);
   }
   $window->add($vbox);
-  $window->signal_connect(delete_event => \&quit_fn);
   $window;
 }
 
-sub quit_fn {
-  Gtk3->main_quit;
-  return 0;
+sub show {
+  my $self = shift;
+  $self->window->show_all;
 }
 
 sub click_btn {
   my ($self, $i, $j, $btn, $evt) = @_;
+  return if $self->complete;
   my $safe = $self->minefield->click($i, $j);
-  if($self->minefield->complete) {
-    if($self->minefield->lives > 0) {
-      $self->info->set_text("You won with @{[$self->minefield->lives]} remaining");
-    } else {
-      $self->info->set_text("You Lost");
-    }
-    return;
-  }
   if($safe) {
     $btn->set_label($safe);
   } else {
     $self->info->set_text($self->minefield->lives);
     $btn->set_label('*');
   }
+  if($self->minefield->complete) {
+    $self->complete(1);
+    if($self->minefield->lives > 0) {
+      $self->info->set_text("You won with @{[$self->minefield->lives]} remaining");
+    } else {
+      $self->info->set_text("You Lost");
+    }
+  }
 }
 
 1;
